package de.kwoxer.www;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Image;
import java.io.File;
import javax.swing.JComponent;
import com.sun.jimi.core.Jimi;

public class Model extends JComponent {
	/**
	 * @author kwoxer
	 */
	private static final long serialVersionUID = 1L;
	private Image image;
	private ColorFilter colorFilter;
	private boolean redDetection = true;
	private final static byte RED = 0, GREEN = 1, BLUE = 2;
	private final static int ABSTAND1 = 30, ABSTAND2 = 300;

	public void setRedDetection(boolean redDetection) {
		this.redDetection = redDetection;
	}

	public void setImage(File file) {
		colorFilter = new ColorFilter(file.getAbsolutePath());
		image = Jimi.getImage(file.getAbsolutePath());
		if (image != null)
			repaint();
	}

	@Override
	protected void paintComponent(Graphics g) {

		if (image != null) {
			// Normal pic
			g.drawImage(image, ABSTAND2 + 100, ABSTAND1, this);

			// Edited pic
			float[][][] redDet = null;
			int[][][] rgbDet = null;
			if (redDetection) {
				redDet = new float[colorFilter.getWidth()][colorFilter.getHeight()][3];
				redDet = colorFilter.filterRed();
			} else {
				rgbDet = new int[colorFilter.getWidth()][colorFilter.getHeight()][3];
				rgbDet = colorFilter.filterRBG();
			}
			for (int i = 0; i < colorFilter.getWidth(); i++) {
				for (int j = 0; j < colorFilter.getHeight(); j++) {
					if (redDetection)
						showRed(g, i, j, redDet);
					else {
						showRGB(g, i, j, rgbDet, RED);
						showRGB(g, i, j, rgbDet, GREEN);
						showRGB(g, i, j, rgbDet, BLUE);
					}
				}
			}
			if (redDetection) {
				g.setColor(new Color(0, 0, 0));
				g.drawString("RED Detection", 0, ABSTAND1 / 2);
			} else {
				g.setColor(new Color(0, 0, 0));
				g.drawString("RED", 0, ABSTAND1 / 2);
				g.drawString("GREEN", 0, ABSTAND2 - ABSTAND1 / 2);
				g.drawString("BLUE", ABSTAND2 + 100, ABSTAND2 - ABSTAND1 / 2);
			}
			g.drawString("Original", ABSTAND2 + 100, ABSTAND1 / 2);
		}
	}

	private void showPixel(Graphics g, int x, int y, Color colors) {
		g.setColor(colors);
		g.fillRect(x, y, 1, 1);
	}

	private void showRGB(Graphics g, int x, int y, int[][][] colors, int modi) {
		int color = (colors[x][y][modi]);
		if (modi == RED) {
			x += 0;
			y += ABSTAND1;
		} else if (modi == GREEN) {
			x += 0;
			y += ABSTAND2;
		} else if (modi == BLUE) {
			x += ABSTAND2 + 100;
			y += ABSTAND2;
		}
		showPixel(g, x, y, new Color(color, color, color));
	}

	private void showRed(Graphics g, int x, int y, float[][][] colors) {
		float hue = (colors[x][y][0]), saturation = (colors[x][y][1]), value = (colors[x][y][2]);
		y += ABSTAND1;
		if ((hue < 0.1 || hue > 0.9) && (saturation > 0.2 && saturation < 1))
			showPixel(g, x, y, new Color(255, 255, 255));
		else
			showPixel(g, x, y, new Color(0, 0, 0));
	}
}